==> intel-media-driver_22.2.0+dfsg1.orig.tar.xz: media-driver-intel-media-22.2.0/media_softlet/agnostic/common/media_interfaces/media_srcs.cmake <==
# Copyright (c) 2021, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/media_interfaces_mhw_next.h
)

set(SOURCES_
    ${SOURCES_}
    ${TMP_SOURCES_}
 )

set(HEADERS_
    ${HEADERS_}
    ${TMP_HEADERS_}
)

set(COMMON_SOURCES_
    ${COMMON_SOURCES_}
    ${TMP_SOURCES_}
)

set(COMMON_HEADERS_
    ${COMMON_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( "SharedNext\\shared" FILES ${TMP_SOURCES_} ${TMP_HEADERS_} )

media_add_curr_to_include_path()

==> intel-media-driver_23.1.1+dfsg1.orig.tar.xz: media-driver-intel-media-23.1.1/media_softlet/agnostic/common/media_interfaces/media_srcs.cmake <==
# Copyright (c) 2021-2022, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/media_interfaces_mhw_next.h
    ${CMAKE_CURRENT_LIST_DIR}/media_interfaces_mcpy_next.h
    ${CMAKE_CURRENT_LIST_DIR}/media_interfaces_codechal_next.h
    ${CMAKE_CURRENT_LIST_DIR}/skuwa_factory.h
)

 if(${MMC_Supported} STREQUAL "yes")
    set(TMP_HEADERS_
        ${TMP_HEADERS_}
        ${CMAKE_CURRENT_LIST_DIR}/media_interfaces_mmd_next.h
    )
endif()


set(SOFTLET_COMMON_SOURCES_
    ${SOFTLET_COMMON_SOURCES_}
    ${TMP_SOURCES_}
)

set(SOFTLET_COMMON_HEADERS_
    ${SOFTLET_COMMON_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( "SharedNext\\shared" FILES ${TMP_SOURCES_} ${TMP_HEADERS_} )

set(SOFTLET_COMMON_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_COMMON_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)
